OC.L10N.register(
    "core",
    {
    "Please select a file." : "Välj en fil.",
    "File is too big" : "Filen är för stor",
    "The selected file is not an image." : "Den valda filen är ingen bild.",
    "The selected file cannot be read." : "Den valda filen kan inte läsas.",
    "The file was uploaded" : "Filen har laddats upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uppladdade filen är större än vad som tillåts av upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-direktivet som specificerades i HTML-formuläret",
    "The file was only partially uploaded" : "Filen är endast delvist uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "Saknar en tillfällig mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdningen",
    "Invalid file provided" : "En ogiltig fil tillhandahölls",
    "No image or file provided" : "Ingen bild eller fil har tillhandahållits",
    "Unknown filetype" : "Okänd filtyp",
    "An error occurred. Please contact your admin." : "Ett fel har inträffat. Kontakta din administratör.",
    "Invalid image" : "Ogiltig bild",
    "No temporary profile picture available, try again" : "Ingen temporär profilbild finns tillgänglig, försök igen",
    "No crop data provided" : "Inga beskärningsdata har angivits",
    "No valid crop data provided" : "Ingen giltig beskärningsdata tillhandahölls",
    "Crop is not square" : "Beskärning är inte kvadratisk",
    "State token does not match" : "Tillstånds-token matchar inte",
    "Invalid app password" : "Felaktigt app-lösenord",
    "Could not complete login" : "Kunde inte slutföra inloggningen",
    "State token missing" : "Statustoken saknas",
    "Your login token is invalid or has expired" : "Din inloggnings-token är ogiltigt eller har gått ut",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Denna community-release av Nextcloud stöds inte och pushnotifikationer är begränsade.",
    "Login" : "Logga in",
    "Unsupported email length (>255)" : "E-postlängd som inte stöds (>255)",
    "Password reset is disabled" : "Lösenordsåterställning är avaktiverat",
    "Could not reset password because the token is expired" : "Kunde inte återställa lösenord eftersom token har utgått",
    "Could not reset password because the token is invalid" : "Kunde inte återställa lösenord eftersom token är ogiltigt",
    "Password is too long. Maximum allowed length is 469 characters." : "Lösenordet är för långt. Högsta tillåtna längd är 469 tecken.",
    "%s password reset" : "%s återställ lösenord",
    "Password reset" : "Lösenordsåterställning",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klicka på knappen för att återställa ditt lösenord.  Om du inte har begärt att återställa ditt lösenord så kan du ignorera detta epost, inget kommer då att ske.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klicka på länken för att återställa ditt lösenord. Om du inte har begärt att lösenordet ska återställas så kan du ignorera detta epost.",
    "Reset your password" : "Återställ ditt lösenord",
    "The given provider is not available" : "Den efterfrågade leverantören är inte tillgänglig",
    "Task not found" : "Uppgiften hittades inte",
    "Internal error" : "Internt fel",
    "Not found" : "Hittades inte",
    "Bad request" : "Felaktigt anrop",
    "Requested task type does not exist" : "Den begärda uppgiftstypen finns inte",
    "Necessary language model provider is not available" : "Nödvändig språkmodellsleverantör är inte tillgänglig",
    "No text to image provider is available" : "Ingen text till bildleverantör är tillgänglig",
    "Image not found" : "Bilden kunde inte hittas",
    "No translation provider available" : "Ingen översättning tillgänglig",
    "Could not detect language" : "Kunde inte identifiera språk",
    "Unable to translate" : "Kan inte översätta",
    "Nextcloud Server" : "Nextcloud-server",
    "Some of your link shares have been removed" : "Några av dina delade länkar har tagits bort",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grund av ett säkerhetsfel var vi tvungna att ta bort några av dina delade länkar. Se länken för mer information.",
    "The account limit of this instance is reached." : "Maximalt antal konton för denna instans har uppnåtts.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ange din prenumerationsnyckel i supportappen för att öka användargränsen. Detta ger dig också alla ytterligare fördelar som Nextcloud Enterprise erbjuder och rekommenderas starkt för användning i företag.",
    "Learn more ↗" : "Läs mer ↗",
    "Preparing update" : "Förbereder uppdatering",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Reparationssteg: ",
    "Repair info:" : "Reparationsinfo:",
    "Repair warning:" : "Reparationsvarning:",
    "Repair error:" : "Reparationsfel:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Var vänlig och uppdatera via kommandotolken då uppdatering via webbläsaren är inaktiverat i config.php",
    "Turned on maintenance mode" : "Aktiverade underhållsläge",
    "Turned off maintenance mode" : "Inaktivera underhållsläge",
    "Maintenance mode is kept active" : "Underhållsläget förblir aktiverat",
    "Updating database schema" : "Uppdaterar databasschema",
    "Updated database" : "Uppdaterade databasen",
    "Update app \"%s\" from App Store" : "Uppdatera appen \"%s\" från appbutiken",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontrollerar om databasschema för %s kan uppdateras (detta kan ta lång tid beroende på databasens storlek)",
    "Updated \"%1$s\" to %2$s" : "Uppdaterade \"%1$s\" till %2$s",
    "Set log level to debug" : "Sätter loggningsnivå till \"debug\"",
    "Reset log level" : "Återställer loggningsnivå",
    "Starting code integrity check" : "Startar integritetskontroll av kod",
    "Finished code integrity check" : "Slutförde integritetskontroll av kod",
    "%s (incompatible)" : "%s (inkompatibel)",
    "The following apps have been disabled: %s" : "Följande appar har inaktiverats: %s",
    "Already up to date" : "Redan uppdaterad",
    "Error occurred while checking server setup" : "Ett fel inträffade när en kontroll av serverns konfiguration utfördes",
    "For more details see the {linkstart}documentation ↗{linkend}." : "För mer detaljer se {linkstart}dokumentationen ↗{linkend}.",
    "unknown text" : "okänd text",
    "Hello world!" : "Hej världen!",
    "sunny" : "soligt",
    "Hello {name}, the weather is {weather}" : "Hej {name}, vädret är {weather}",
    "Hello {name}" : "Hej {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Detta är ditt sökresultat<script>alert(1)</script></strong>",
    "new" : "ny",
    "_download %n file_::_download %n files_" : ["Ladda ner %n fil","Hämta %n filer"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppdateringen pågår, om sidan lämnas kan uppdateringen misslyckas. ",
    "Update to {version}" : "Uppdatera till {version}",
    "An error occurred." : "Ett fel inträffade.",
    "Please reload the page." : "Uppdatera sidan.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppdateringen misslyckades. För mer information <a href=\"{url}\">se vår forumpost</a> angående problemet.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppdateringen misslyckades. Rapportera felet till <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
    "Continue to {productName}" : "Fortsätt till {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uppdateringen lyckades. Omdirigerar dig till {productName} om %n sekund.","Uppdateringen lyckades. Omdirigerar dig till {productName} om %n sekunder."],
    "Applications menu" : "Appmeny",
    "Apps" : "Appar",
    "More apps" : "Fler appar",
    "_{count} notification_::_{count} notifications_" : ["{count} meddelande","{count} meddelanden"],
    "No" : "Nej",
    "Yes" : "Ja",
    "The remote URL must include the user." : "Den externa adressen måste inkludera användaren.",
    "Invalid remote URL." : "Ogiltig extern adress.",
    "Failed to add the public link to your Nextcloud" : "Misslyckades skapa den offentliga delningslänken till ditt moln",
    "Federated user" : "Federerad användare",
    "user@your-nextcloud.org" : "användare@din-nextcloud.se",
    "Create share" : "Skapa delning",
    "Direct link copied to clipboard" : "Direktlänk kopierad till urklipp",
    "Please copy the link manually:" : "Kopiera länken manuellt:",
    "Custom date range" : "Anpassat datumintervall",
    "Pick start date" : "Välj startdatum",
    "Pick end date" : "Välj slutdatum",
    "Search in date range" : "Sök i datumintervall",
    "Search in current app" : "Sök i nuvarande app",
    "Clear search" : "Rensa sökning",
    "Search everywhere" : "Sök överallt",
    "Searching …" : "Söker ...",
    "Start typing to search" : "Börja skriva för att söka",
    "No matching results" : "Inga matchande resultat",
    "Today" : "Idag",
    "Last 7 days" : "Senaste 7 dagarna",
    "Last 30 days" : "Senaste 30 dagarna",
    "This year" : "Det här året",
    "Last year" : "Förra året",
    "Unified search" : "Enhetlig sökning",
    "Search apps, files, tags, messages" : "Sök efter appar, filer, taggar, meddelanden",
    "Places" : "Platser",
    "Date" : "Datum",
    "Search people" : "Sök efter användare",
    "People" : "Personer",
    "Filter in current view" : "Filtrera i aktuell vy",
    "Results" : "Resultat",
    "Load more results" : "Hämta fler resultat",
    "Search in" : "Sök i",
    "Log in" : "Logga in",
    "Logging in …" : "Loggar in ...",
    "Log in to {productName}" : "Logga in på {productName}",
    "Wrong login or password." : "Felaktigt inloggning eller lösenord.",
    "This account is disabled" : "Detta konto är inaktiverat",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
    "Account name or email" : "Användarnamn eller e-post",
    "Account name" : "Kontonamn",
    "Server side authentication failed!" : "Servern misslyckades med autentisering!",
    "Please contact your administrator." : "Kontakta din administratör.",
    "Session error" : "Sessionsfel",
    "It appears your session token has expired, please refresh the page and try again." : "Det verkar som att din sessionstoken har gått ut, uppdatera sidan och försök igen.",
    "An internal error occurred." : "Ett internt fel uppstod.",
    "Please try again or contact your administrator." : "Försök igen eller kontakta din administratör.",
    "Password" : "Lösenord",
    "Log in with a device" : "Logga in med en enhet",
    "Login or email" : "Användarnamn eller e-post",
    "Your account is not setup for passwordless login." : "Ditt konto är inte inställt för inloggning utan lösenord.",
    "Your connection is not secure" : "Din anslutning är inte säker",
    "Passwordless authentication is only available over a secure connection." : "Lösenordsfri autentisering är endast tillgänglig via en säker anslutning.",
    "Browser not supported" : "Webbläsaren stöds inte",
    "Passwordless authentication is not supported in your browser." : "Lösenordsfri autentisering stöds inte i din webbläsare.",
    "Reset password" : "Återställ lösenord",
    "Back to login" : "Tillbaka till inloggning",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Om det här kontot finns har ett meddelande om lösenordsåterställning skickats till dess e-postadress. Om du inte får det, verifiera din e-postadress och/eller kontonamn, kontrollera dina skräppost-/skräpmappar eller be din lokala administration om hjälp.",
    "Couldn't send reset email. Please contact your administrator." : "Kunde inte skicka återställningsmejl. Kontakta din administratör.",
    "Password cannot be changed. Please contact your administrator." : "Lösenordet kan inte ändras. Vänligen kontakta din administratör.",
    "New password" : "Nytt lösenord",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka din data efter att ditt lösenord har återställs. Om du är osäker på hur du ska göra, kontakta din administratör innan du fortsätter. Är du verkligen säker på att du vill fortsätta?",
    "I know what I'm doing" : "Jag vet vad jag gör",
    "Resetting password" : "Återställer lösenord",
    "Schedule work & meetings, synced with all your devices." : "Planera arbete och möten, synkronisera med alla dina enheter.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Håll dina kollegor och vänner på ett ställe utan att läcka deras privata info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app integrerad med filer, kontakter och kalender.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatt, videosamtal, skärmdelning, onlinemöten och webbkonferenser – i din webbläsare och med mobilappar.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kollaborativa dokument, kalkylark och presentationer, byggt på Collabora Online",
    "Distraction free note taking app." : "Distraktionsfri anteckningsapp.",
    "Recommended apps" : "Rekommenderade appar",
    "Loading apps …" : "Läser in appar …",
    "Could not fetch list of apps from the App Store." : "Det gick inte att hämta listan över appar från App Store.",
    "App download or installation failed" : "Hämtning eller installation av appen misslyckades",
    "Cannot install this app because it is not compatible" : "Appen kan inte installeras eftersom den inte är kompatibel",
    "Cannot install this app" : "Kan inte installera denna app",
    "Skip" : "Hoppa över",
    "Installing apps …" : "Installerar appar ...",
    "Install recommended apps" : "Installera rekommenderade appar",
    "Avatar of {displayName}" : "Avatar för {displayName}",
    "Settings menu" : "Inställningsmeny",
    "Loading your contacts …" : "Läser in dina kontakter ...",
    "Looking for {term} …" : "Letar efter {term} …",
    "Search contacts" : "Sök kontakter",
    "Reset search" : "Återställ sökning",
    "Search contacts …" : "Sök kontakter ...",
    "Could not load your contacts" : "Det gick inte att läsa in dina kontakter",
    "No contacts found" : "Inga kontakter hittades",
    "Show all contacts" : "Visa alla kontakter",
    "Install the Contacts app" : "Installera appen Kontakter",
    "Search" : "Sök",
    "No results for {query}" : "Inga resultat för {query}",
    "Press Enter to start searching" : "Tryck på enter för att börja söka",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Ange {minSearchLength} tecken eller mer för att söka","Ange {minSearchLength} tecken eller mer för att söka"],
    "An error occurred while searching for {type}" : "Ett fel uppstod vid sökning efter {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Sökningen startar när du börjar skriva och resultat kan nås med piltangenterna",
    "Search for {name} only" : "Sök efter endast {name}",
    "Loading more results …" : "Hämtar fler resultat ...",
    "Forgot password?" : "Glömt lösenordet?",
    "Back to login form" : "Tillbaka till inloggningsformulär",
    "Back" : "Tillbaka",
    "Login form is disabled." : "Inloggningsfomuläret är inaktiverat.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Inloggningsformuläret är inaktiverat. Använd om tillgänglig en annan inloggnings-metod eller kontakta administrationen.",
    "More actions" : "Fler händelser",
    "Password is too weak" : "Lösenordet är för svagt",
    "Password is weak" : "Lösenordet är svagt",
    "Password is average" : "Lösenordet är medelstarkt",
    "Password is strong" : "Lösenordet är starkt",
    "Password is very strong" : "Lösenordet är mycket starkt",
    "Password is extremely strong" : "Lösenordet är extremt starkt",
    "Unknown password strength" : "Okänd lösenordsstyrka",
    "Security warning" : "Säkerhetsvarning",
    "Create administration account" : "Skapa administratörskonto",
    "Administration account name" : "Namn på administratörskonto",
    "Administration account password" : "Lösenord för administratörskonto",
    "Storage & database" : "Lagring & databas",
    "Data folder" : "Datamapp",
    "Install and activate additional PHP modules to choose other database types." : "Installera och aktivera ytterligare moduler för att kunna välja andra databas-typer.",
    "For more details check out the documentation." : "För mer detaljer se dokumentationen",
    "Performance warning" : "Prestandavarning",
    "You chose SQLite as database." : "Du valde SQLite som databas.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bör endast användas till små installationer och installationer avsedda för utveckling. För produktion rekommenderar vi byte till annan databas.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Om du använder synkklienter avråder vi starkt från användning av SQLite.",
    "Database user" : "Databasanvändare",
    "Database password" : "Lösenord till databasen",
    "Database name" : "Databasnamn",
    "Database tablespace" : "Databas tabellutrymme",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vänligen ange portnumret tillsammans med värdnamnet (t.ex. localhost:5432).",
    "Database host" : "Databasserver",
    "Installing …" : "Installerar …",
    "Install" : "Installera",
    "Need help?" : "Behövs hjälp?",
    "See the documentation" : "Se dokumentationen",
    "{name} version {version} and above" : "{name} version {version} och högre",
    "This browser is not supported" : "Den här webbläsaren stöds inte",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din webbläsare stöds inte. Uppgradera till en nyare version eller en som stöds.",
    "Continue with this unsupported browser" : "Fortsätt med webbläsare som inte stöds",
    "Supported versions" : "Stödda versioner",
    "Search {types} …" : "Sök {types} …",
    "Choose {file}" : "Välj {file}",
    "Choose" : "Välj",
    "Copy to {target}" : "Kopiera till {target}",
    "Copy" : "Kopiera",
    "Move to {target}" : "Flytta till {target}",
    "Move" : "Flytta",
    "OK" : "OK",
    "read-only" : "skrivskyddad",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonflikter"],
    "One file conflict" : "En filkonflikt",
    "New Files" : "Nya filer",
    "Already existing files" : "Filer som redan existerar",
    "Which files do you want to keep?" : "Vilka filer vill du behålla?",
    "If you select both versions, the copied file will have a number added to its name." : "Om du väljer båda versionerna kommer de kopierade filerna ha nummer tillagda i filnamnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Fortsätt",
    "(all selected)" : "(Alla valda)",
    "({count} selected)" : "({count} valda)",
    "Error loading file exists template" : "Fel vid inläsning av fil finns i mall",
    "Saving …" : "Sparar ...",
    "seconds ago" : "sekunder sedan",
    "Connection to server lost" : "Anslutning till server förlorad",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem med att läsa in sidan, uppdaterar om %n sekund","Problem med att läsa in sidan, uppdaterar om %n sekunder"],
    "Add to a project" : "Lägg till i ett projekt",
    "Show details" : "Visa detaljer",
    "Hide details" : "Göm detaljer",
    "Rename project" : "Byt namn på projekt",
    "Failed to rename the project" : "Kunde inte byta namn på projektet",
    "Failed to create a project" : "Kunde inte skapa projekt",
    "Failed to add the item to the project" : "Kunde inte lägga till objektet i projektet",
    "Connect items to a project to make them easier to find" : "Koppla objekt till ett projekt för att göra dem enklare att hitta",
    "Type to search for existing projects" : "Skriv för att söka efter befintliga projekt",
    "New in" : "Ny i",
    "View changelog" : "Visa ändringslogg",
    "No action available" : "Ingen åtgärd tillgänglig",
    "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
    "Close \"{dialogTitle}\" dialog" : "Stäng \"{dialogTitle}\"",
    "Email length is at max (255)" : "E-postlängden är max (255)",
    "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
    "Restricted" : "Begränsad",
    "Invisible" : "Osynlig",
    "Delete" : "Ta bort",
    "Rename" : "Byt namn",
    "Collaborative tags" : "Samverkanstaggar",
    "No tags found" : "Hittade inga taggar",
    "Clipboard not available, please copy manually" : "Urklipp är inte tillgängligt, kopiera manuellt",
    "Personal" : "Personliga Inställningar",
    "Accounts" : "Konton",
    "Admin" : "Admin",
    "Help" : "Hjälp",
    "Access forbidden" : "Åtkomst förbjuden",
    "Page not found" : "Sidan hittades inte",
    "The page could not be found on the server or you may not be allowed to view it." : "Sidan kunde inte hittas på servern eller så kanske du inte har behörighet att se den.",
    "Back to %s" : "Tillbaka till %s",
    "Too many requests" : "För många förfrågningar",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det kom för många förfrågningar från ditt nätverk. Försök senare eller kontakta din administratör om detta är ett fel.",
    "Error" : "Fel",
    "Internal Server Error" : "Internt serverfel",
    "The server was unable to complete your request." : "Servern kunde inte slutföra din begäran.",
    "If this happens again, please send the technical details below to the server administrator." : "Om det händer igen, vänligen skicka de tekniska detaljerna nedan till din serveradministratör.",
    "More details can be found in the server log." : "Mer detaljer återfinns i serverns logg.",
    "For more details see the documentation ↗." : "För mer information se dokumentationen ↗.",
    "Technical details" : "Tekniska detaljer",
    "Remote Address: %s" : "Extern adress: %s",
    "Request ID: %s" : "Begärd ID: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Meddelande: %s",
    "File: %s" : "Fil: %s",
    "Line: %s" : "Rad: %s",
    "Trace" : "Spåra",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Det ser ut som att du försöker installera om Nextcloud. Men filen CAN_INSTALL saknas i din konfigurationskatalog. Skapa filen CAN_INSTALL i din konfigurationsmapp för att fortsätta.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Det gick inte att ta bort CAN_INSTALL från konfigurationsmappen. Ta bort den här filen manuellt.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denna applikationen kräver JavaScript för att fungera korrekt. {linkstart}aktivera JavaScript{linkend} och uppdatera sidan.",
    "Skip to main content" : "Skippa till huvudinnehållet",
    "Skip to navigation of app" : "Skippa till navigering av app",
    "Go to %s" : "Gå till %s",
    "Get your own free account" : "Skaffa ett eget gratiskonto",
    "Connect to your account" : "Anslut ditt konto",
    "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Om du inte försöker konfigurera en ny enhet eller app, försöker någon lura dig att ge dem åtkomst till din data. Fortsätt i så fall inte, utan kontakta istället din systemadministratör.",
    "App password" : " Applösenord",
    "Grant access" : "Tillåt åtkomst",
    "Alternative log in using app password" : "Alternativ inloggning med applösenord",
    "Account access" : "Kontoåtkomst",
    "Currently logged in as %1$s (%2$s)." : "För närvarande inloggad som %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Du håller på att ge %1$s åtkomst till ditt %2$s konto.",
    "Account connected" : "Konto anslutet",
    "Your client should now be connected!" : "Din klient ska nu vara ansluten!",
    "You can close this window." : "Du kan stänga det här fönstret.",
    "Previous" : "Föregående",
    "This share is password-protected" : "Denna delning är lösenordsskyddad",
    "The password is wrong or expired. Please try again or request a new one." : "Lösenordet är fel eller har gått ut. Försök igen eller begär ett nytt.",
    "Please type in your email address to request a temporary password" : "Skriv in din e-postadress för att begära ett tillfälligt lösenord",
    "Email address" : "E-postadress",
    "Password sent!" : "Lösenord skickat!",
    "You are not authorized to request a password for this share" : "Du har inte behörighet att begära ett lösenord för denna delning",
    "Two-factor authentication" : "Tvåfaktorsautentisering",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj en andra faktor för autentisering:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Det gick inte att läsa in minst en av dina aktiverade tvåfaktorsautentiseringsmetoder. Vänligen kontakta din systemadministratören.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Kontakta din administratör för hjälp.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Fortsätt och konfigurera tvåfaktorsautentisering.",
    "Set up two-factor authentication" : "Ställ in tvåfaktorsautentisering",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Använd en av dina säkerhetskoder för att logga in eller kontakta din administratör för hjälp.",
    "Use backup code" : "Använd reservkod",
    "Cancel login" : "Avbryt inloggning",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj vilken leverantör du vill konfigurera:",
    "Error while validating your second factor" : "Fel vid verifiering av tvåfaktorsautentisering.",
    "Access through untrusted domain" : "Åtkomst genom obetrodd domän",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Vänligen kontakta din administratör. Om du är en administratör, ändra \"trusted_domains\"-inställningen i config/config.php likt exemplet i config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ytterligare information hur du konfigurerar detta finns i %1$sdokumentationen%2$s.",
    "App update required" : "Appen behöver uppdateras",
    "%1$s will be updated to version %2$s" : "%1$s kommer att uppdateras till version %2$s",
    "The following apps will be updated:" : "Följande appar kommer att uppdateras:",
    "These incompatible apps will be disabled:" : "Dessa inkompatibla appar kommer att inaktiveras",
    "The theme %s has been disabled." : "Temat  %s har blivit inaktiverat.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Säkerställ att en säkerhetskopia har gjorts av databasen, konfigurations- och datamappen innan du fortsätter.",
    "Start update" : "Påbörja uppdateringen",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "För att undvika timeout vid större installationer kan du istället köra följande kommando från din installationskatalog:",
    "Detailed logs" : "Detaljerade loggar",
    "Update needed" : "Uppdatering krävs",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Använd kommandoradsuppdateringen eftersom du har en stor instans med mer än 50 konton.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "För hjälp, se  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentationen</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jag vet att om jag fortsätter göra uppdateringen via webbgränssnittet innebär risken att begäran får timeout och kan orsaka dataförluster men att jag har en backup och vet hur instansen återställs i fall fel uppstår.",
    "Upgrade via web on my own risk" : "Uppgradera via webben på min egen risk",
    "Maintenance mode" : "Underhållsläge",
    "This %s instance is currently in maintenance mode, which may take a while." : "Denna %s-instans befinner sig för närvarande i underhållsläge, vilket kan ta ett tag.",
    "This page will refresh itself when the instance is available again." : "Denna sida uppdaterar sig själv när instansen är tillgänglig igen.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hör av dig till din systemadministratör om detta meddelande fortsätter eller visas oväntat.",
    "Currently open" : "För närvarande öppen",
    "Login with username or email" : "Logga in med användarnamn eller e-post",
    "Login with username" : "Logga in med användarnamn",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatt, videosamtal, skärmdelning, onlinemöten och webbkonferenser – i din webbläsare och med mobilappar.",
    "You have not added any info yet" : "Du har inte angivit någon information ännu",
    "{user} has not added any info yet" : "{user} har inte angivit någon information ännu",
    "Error opening the user status modal, try hard refreshing the page" : "Kunde inte öppna användarstatus-rutan, försök att ladda om sidan",
    "Edit Profile" : "Redigera profil",
    "The headline and about sections will show up here" : "Rubriken och avsnitten \"om\" kommer att dyka upp här",
    "Error loading message template: {error}" : "Fel uppstod under inläsningen av meddelandemallen: {error}",
    "Very weak password" : "Väldigt svagt lösenord",
    "Weak password" : "Svagt lösenord",
    "So-so password" : "Okej lösenord",
    "Good password" : "Bra lösenord",
    "Strong password" : "Starkt lösenord",
    "Profile not found" : "Profil kunde inte hittas",
    "The profile does not exist." : "Profilen existerar inte.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Din datakatalog och filer är förmodligen tillgängliga från Internet eftersom filen .htaccess inte fungerar.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Information hur din server bäst konfigureras kan hittas i <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Skapa ett administratörskonto</strong>",
    "New admin account name" : "Namn på administratörskonto",
    "New admin password" : "Lösenord för administratörskonto",
    "Show password" : "Visa lösenord",
    "Toggle password visibility" : "Växla lösenordsynlighet",
    "Configure the database" : "Konfigurera databasen",
    "Only %s is available." : "Endast %s är tillgänglig.",
    "Database account" : "Databaskonto"
},
"nplurals=2; plural=(n != 1);");
